uniform mat4 uMVPMatrix;
uniform vec4 uColorPatterns[10]; //DEBUG
uniform int uColorPatternsCount;

const float cUVTZScaleFactor = 1.0 / 255.0;
const float cOffTheScreenParticlePosition = 50000.0;

attribute vec2 aParticleVertex;
attribute vec2 aParticlePosition;
attribute vec2 aParticleTextureCoordinate;
attribute vec4 aUVTA;

varying lowp vec4 vPaletteColor;
varying vec2 vParticleTextureCoordinate;
varying lowp float vAlpha;

void main() {
	int index = uColorPatternsCount - 1;
    while (length(aUVTA.xy) < uColorPatterns[index].a && index > 0)
    {
        --index;
    }
    
    vPaletteColor = vec4(uColorPatterns[index].rgb, 1.0);
    vParticleTextureCoordinate = aParticleTextureCoordinate;
	vAlpha = aUVTA.w;

	vec2 particlePosition = aParticlePosition;

    float angle = atan(aUVTA.x, aUVTA.y);
    mat2 rotationMatrix = mat2(cos(angle), -sin(angle), sin(angle), cos(angle)); // columns are passed

    vec2 rotatedParticleVertex = rotationMatrix * aParticleVertex;

    vec4 particleVertex =  vec4(particlePosition.x + rotatedParticleVertex.x, particlePosition.y + rotatedParticleVertex.y, 0.0, 1.0);

    gl_Position = uMVPMatrix * particleVertex;
}